@@ -1,7 +1,7 @@
 package Pod::Weaver::Section::Homepage::DefaultCPAN;
 
-our $DATE = '2015-04-01'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -22,7 +22,7 @@ sub weave_section {
   my $homepage = $input->{distmeta}{resources}{homepage} //
       "https://metacpan.org/release/$name";
 
-  my $text = sprintf $self->text, $homepage;
+  my $text = sprintf($self->text, $homepage) . "\n\n";
 
   #$text = Text::Wrap::wrap(q{}, q{}, $text);
 
@@ -45,7 +45,7 @@ Pod::Weaver::Section::Homepage::DefaultCPAN - Add a HOMEPAGE section (homepage d
 
 =head1 VERSION
 
-This document describes version 0.04 of Pod::Weaver::Section::Homepage::DefaultCPAN (from Perl distribution Pod-Weaver-Section-Homepage-DefaultCPAN), released on 2015-04-01.
+This document describes version 0.05 of Pod::Weaver::Section::Homepage::DefaultCPAN (from Perl distribution Pod-Weaver-Section-Homepage-DefaultCPAN), released on 2015-04-02.
 
 =head1 SYNOPSIS
 
@@ -84,9 +84,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Section-Homepage-DefaultCPAN>.
-
-=head1 BUGS
+Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Section-Homepage-DefaultCPAN>.=head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Weaver-Section-Homepage-DefaultCPAN>
 
